@@ -156,7 +156,7 @@ IP::~IP()
 
 /*  Get IP header-length
  */
-u_int8_t IP::get_hlen()
+u_int8_t IP::get_hlen() const
 {
    	return iph.ihl;
 }
@@ -171,7 +171,7 @@ int IP::set_hlen(u_int8_t l)
 
 /* Get Ip-version field.
  */
-u_int8_t IP::get_vers()
+u_int8_t IP::get_vers() const
 {
    	return iph.version;
 }
@@ -184,7 +184,7 @@ int IP::set_vers(u_int8_t v)
         return 0;
 }
  
-u_int8_t IP::get_tos()
+u_int8_t IP::get_tos() const
 {
    	return iph.tos;
 }
@@ -197,7 +197,7 @@ int IP::set_tos(u_int8_t tos)
 
 /* Get total length of IP-packet.
  */
-u_int16_t IP::get_totlen()
+u_int16_t IP::get_totlen() const
 {
    	return ntohs(iph.tot_len);
 }
@@ -233,7 +233,7 @@ int IP::set_totlen(u_int16_t t)
 
 /* Get the IP id field.
  */
-u_int16_t IP::get_id()
+u_int16_t IP::get_id() const
 {
    	return ntohs(iph.id);
 }
@@ -247,7 +247,7 @@ int IP::set_id(u_int16_t id)
 }
 
 /* Get the IP-fragmentation offset */
-u_int16_t IP::get_fragoff()
+u_int16_t IP::get_fragoff() const
 {
    	return ntohs(iph.frag_off);
 }
@@ -269,7 +269,7 @@ int IP::set_fragoff(u_int16_t f)
 
 /* Get time to live.
  */
-u_int8_t IP::get_ttl()
+u_int8_t IP::get_ttl() const
 {
    	return iph.ttl;
 }
@@ -284,7 +284,7 @@ int IP::set_ttl(u_int8_t ttl)
 
 /* Obtain the actuall protocol.
  */
-u_int8_t IP::get_proto()
+u_int8_t IP::get_proto() const
 {
    	return iph.protocol;
 }
@@ -300,7 +300,7 @@ int IP::set_proto(u_int8_t p)
 
 /* Get IP-header checksum 
  */
-u_int16_t IP::get_sum()
+u_int16_t IP::get_sum() const
 {
 	   	return iph.check;
 }
@@ -343,7 +343,7 @@ int IP::set_sum(u_int16_t s)
 
 /* Get the destination-adress in networkbyteorder.
  */
-u_int32_t IP::get_dst()
+u_int32_t IP::get_dst() const
 {
 	return iph.daddr;
 }
@@ -369,7 +369,7 @@ char *IP::get_dst(int resolv, char *s, size_t len)
 /* Return the source-adress of actuall IP-packet
  * in network-byte order.
  */
-u_int32_t IP::get_src()
+u_int32_t IP::get_src() const
 {
    	return iph.saddr;
 }
@@ -435,11 +435,16 @@ int IP::set_dst(const char* host)
         return 0;
 }
 
-iphdr IP::get_iphdr()
+iphdr IP::get_iphdr() const
 {
 	return iph;
 }
 
+int IP::set_iphdr(struct iphdr _iph) {
+	iph = _iph;
+	return 0;
+}
+
 /* Send a packet, containing 'paylen' bytes of data.
  */
 int IP::sendpack(void *payload, size_t paylen)
@@ -497,13 +502,13 @@ int IP::sniffpack(void *buf, size_t len)
 {
 	int r = 0;
 	int xlen = len + sizeof(iph) + sizeof(ipOptions);
-        struct usipp::iphdr *i = NULL;
+	struct usipp::iphdr *i = NULL;
         
-        char *tmp = new char[xlen];
+	char *tmp = new char[xlen];
 	memset(tmp, 0, xlen);
 	memset(buf, 0, len);
         
-        /* until we assembled fragments or we received and unfragemented packet
+	/* until we assembled fragments or we received and unfragemented packet
 	 */
 	while (i == NULL) {
 		memset(tmp, 0, xlen);
@@ -677,6 +682,17 @@ char *IP::reassemble(char *packet, int len, int *resultLen)
         }
 }
 	
+std::string IP::to_string(void) {
+	char buf[4096], src_str[256], dst_str[256];
+	string retval;
+	
+	memset(buf, 0, sizeof(buf));
+	// hrm using inet_ntoa() two times in a row in one snprintf statement
+	// cases it to display the same IP for both, while they are actually different
+	snprintf(buf, sizeof(buf), "+--------------------------------[ IP ]\n| src=%s dst=%s hlen=%d totlen=%d tos=0x%x fragoff=0x%x ttl=%d id=%d\n+--------------------------------\n", get_src(0, src_str, sizeof(src_str)), get_dst(0, dst_str, sizeof(dst_str)), get_hlen(), get_totlen(), get_tos(), get_fragoff(), get_ttl(), get_id());	
+	retval = buf;
+	return retval;
+}
 
 } // namespace usipp
 
