@@ -1,4 +1,4 @@
-/* $Id: cmd_opts.h,v 1.12 2004/11/29 06:03:49 mederchik Exp $ */
+/* $Id: cmd_opts.h,v 1.14 2005/02/14 18:05:17 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -44,7 +44,7 @@ class Cmd_Opts {
         char *default_config_file;
         unsigned long debuglevel;
         char *target;
-		bool showroute, portscan, rtt_forced, sgen, xml, brute_force_tcp_ports;
+		bool showroute, portscan, rtt_forced, sgen, xml, brute_force_tcp_ports, analyze_samples;
 		map <int, char> tcp_ports;
 		map <int, char> udp_ports;
 		vector <Port_Range> tcp_ports_toscan;
@@ -53,7 +53,6 @@ class Cmd_Opts {
 		int numofmatches;
 		int parse_port(char *);
 		int parse_range(char *, vector<Port_Range> *);
-		int tokenize(const char *, char, vector<string> *); 
     public:
         Cmd_Opts(void);
         int is_verbose(void);
@@ -75,6 +74,7 @@ class Cmd_Opts {
 		bool generate_sig() { return sgen; }
 		bool do_xml();
 		bool tcp_port_brute();
+		bool analyze_packets() { return analyze_samples; }
 		vector<Port_Range> *get_tcp_ports_to_scan() { return &tcp_ports_toscan; }
 		vector<Port_Range> *get_udp_ports_to_scan() { return &udp_ports_toscan; }
 };
