@@ -1,4 +1,4 @@
-/* $Id: config_set.h,v 1.7 2004/08/28 10:49:55 mederchik Exp $ */
+/* $Id: config_set.h,v 1.8 2005/07/21 11:42:31 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -130,10 +130,12 @@ class Config_Set {
 		bool showroute;
         map <int, char> *tcp_ports;
         map <int, char> *udp_ports;
+		string comstrings;
     public:
+        Config_Set();
+        ~Config_Set(void);
         void set_timeout(int t) { timeout = t; }
         int  get_timeout(void) { return timeout; }
-        Config_Set();
         int read_config(char *);
 		bool show_route(void) { return showroute; }
 		void show_route(bool sr) { showroute = sr; }
@@ -141,7 +143,8 @@ class Config_Set {
 		map <int, char> *get_udp_ports(void) { return udp_ports; }
 		void set_tcp_ports(map <int, char> *tp) { tcp_ports = tp; }
 		void set_udp_ports(map <int, char> *up) { udp_ports = up; }
-        ~Config_Set(void);
+		void set_comstrings(string v) { comstrings = v; }
+		string get_comstrings(void) { return comstrings; }
 };
 
 #endif /* CONFIG_SET_H */
