@@ -1,4 +1,4 @@
-/* $Id: os_matrix.cc,v 1.6 2005/02/08 20:00:33 mederchik Exp $ */
+/* $Id: os_matrix.cc,v 1.8 2005/07/18 11:08:24 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -109,12 +109,14 @@ const string OS_Name::osid2str(int id) {
 OS_Vector::OS_Vector(int new_os_id) {
     os_id = new_os_id;
     total = 0;
+	numofkwds=0;
 }
 
 void OS_Vector::add_result(int test_id, int score) {
     xprobe_debug(XPROBE_DEBUG_OSMATRIX, "added: test_id: %i score: %i\n",
      test_id, score);
     total += score;
+	numofkwds++;
 }
 
 bool os_vector_compare(const OS_Vector &a, const OS_Vector &b) {
@@ -157,7 +159,9 @@ void OS_Matrix::add_result(int test_id, int os_id, int score, int times) {
         osid_vec.push_back(OS_Vector(os_id));
 
     i = find_os_id(os_id);
-    osid_vec[i].add_result(test_id, score * times);
+	while (times-- > 0) {			
+	    osid_vec[i].add_result(test_id, score);
+	}
 }
 
 int OS_Matrix::get_score(int os_id) {
@@ -167,16 +171,18 @@ int OS_Matrix::get_score(int os_id) {
     return (osid_vec[find_os_id(os_id)].get_total());
 }
 
-int OS_Matrix::get_max_score(void) {
-
-    return (xp_loaded_mods * XPROBE_MATCH_YES);
+int OS_Matrix::get_max_score(int os_id) {
+	int i = find_os_id(os_id);
+	
+    //return (xp_loaded_mods * XPROBE_MATCH_YES);
+	return (osid_vec[i].get_number_of_keywords() * XPROBE_MATCH_YES);
 
 }
 
 int OS_Matrix::get_prcnt_score(int os_id) {
 
     if (get_score(os_id) < 0) return 0;	
-    return get_score(os_id) * 100/get_max_score();
+    return get_score(os_id) * 100/get_max_score(os_id);
 
 }
 
