@@ -45,5 +45,12 @@ struct in_addr xp_get_src_addr(struct in_addr dst) {
 		perror("xp_get_src_addr(): getsockname");
 		exit(1);
 	}	
+
+	//KPC 1-17-05 - Close socket connection to address handle leak
+	if (close(sockfd) < 0) {
+		perror("xp_get_src_addr(): close");
+		exit(1);
+	}
+
 	return src.sin_addr;
 }
