@@ -33,6 +33,11 @@ class xp_lib {
 		static int tokenize(const char *, char, vector<string> *);
 		static int tokenize(const char *, char, vector<int> *);
 		static string int_to_string(int);
+		static int OpenTCPSession( struct in_addr dst_IP, unsigned short dst_port );
+		static int RecvTimeout( int sock, unsigned char *bufr, int bsize, int timeout );
+		static bool equal(const char *, const char *);
+		static bool equal(string, string);
+		static int OpenUDPSocket(struct sockaddr_in *to, struct sockaddr_in *bind_sin=NULL);
 };
 
 #endif
