@@ -229,6 +229,8 @@ sniff_again:
 		value = "<";
 		if (ttl <= 32)
 			value.append("32");
+		else if (ttl <= 60)
+			value.append("60");
 		else if (ttl <= 64)
 			value.append("64");
 		else if (ttl <= 128)
@@ -373,11 +375,10 @@ sniff_again:
 	*/
 	if (echoed_dtsize > 64) {
 		value = ">64";
-		fingerptr->put_echoed_size(value.c_str());
-	} else if (echoed_dtsize < 64) {
+	} else {
 		value = xp_lib::int_to_string(echoed_dtsize);
-		fingerptr->put_echoed_size(value.c_str());
 	}
+	fingerptr->put_echoed_size(value.c_str());
 	if (gensig) Tgt->signature(keyword, value);
 	
 free(payload);
