@@ -1,4 +1,4 @@
-/* $Id: icmp_port_unreach.h,v 1.7 2003/08/05 03:35:12 mederchik Exp $ */
+/* $Id: icmp_port_unreach.h,v 1.9 2005/02/15 15:15:52 mederchik Exp $ */
 /*
 ** Copyright (C) 2001, 2002 Meder Kydyraliev
 **
@@ -41,6 +41,7 @@
 
 #define IPID_SENT	2
 
+#define ICMP_UNREACH_DEF_PORT 65534
 #ifndef __USE_BSD
 #define __USE_BSD
 #endif
@@ -66,8 +67,9 @@ class icmp_port_unreach: public Xprobe_Module {
 			u_char echoed_ipid;		/* values: [OK, FLIPPED] */
 			int echoed_totlen;		/* values: [<20, OK, >20] */
 			u_char echoed_3bit_flags;	/* values: [OK, FLIPPED] */
+			bool reply;
         public:
-			Fingerprint (void) { icmp_port_unreach_ttl=0;}
+			Fingerprint (void) { icmp_port_unreach_ttl=0; }
             u_short get_p_unreach_ttl (void) { return icmp_port_unreach_ttl;}
 			u_char get_icmp_prec_bits (void) { return icmp_precedence_bits; }
 			u_char get_icmp_df (void) { return icmp_ip_df; }
@@ -78,6 +80,7 @@ class icmp_port_unreach: public Xprobe_Module {
 			int get_echoed_totlen (void) { return echoed_totlen; }
 			u_char get_echoed_3bit (void) { return echoed_3bit_flags; }
 			u_char get_icmp_ipid(void) { return icmp_ipid; }
+			bool get_reply(void) { return reply; }
 			
             void put_p_unreach_ttl (const char *v) { icmp_port_unreach_ttl = atoi(v) - 1; }
 			void put_p_unreach_ttl (int v)	{ icmp_port_unreach_ttl = v; }
@@ -147,6 +150,13 @@ class icmp_port_unreach: public Xprobe_Module {
 				else if (!strncasecmp(v, "SENT", 4))
 					icmp_ipid = IPID_SENT;
 			}
+			void put_reply(const char *v) {
+				if (v[0] == 'Y' || v[0] == 'y')
+					reply = true;
+				else 
+					reply = false;
+								
+			}
 			
     };
 	/* MAP TO STORE FINGEPRINTS */
