@@ -87,7 +87,7 @@ int TCP_Handshake_Mod::run_probe(Target *tg, OS_Matrix *os) {
 	int done=0, ret, have_more_ports=1;
 	bool no_open_port;
 	unsigned int ix=0;
-	unsigned short tcp_brute_ports[] = {80, 443, 23, 21, 25, 22, 139, 445, 6000};
+	unsigned short tcp_brute_ports[] = {80, 443, 23, 21, 25, 22, 445, 139, 6000};
 	Xprobe::Timeval tv;
 	struct in_addr local=tg->get_interface_addr(), remote=tg->get_addr();
 	TCP sn(inet_ntoa(local));
@@ -186,13 +186,15 @@ int TCP_Handshake_Mod::run_probe(Target *tg, OS_Matrix *os) {
 					for (w_i = wscale_map.begin(); w_i != wscale_map.end(); w_i++)
 						if (w_i->second == wscale) {
 							os->add_result(get_id(), w_i->first, XPROBE_MATCH_YES);
-						} else
+						} else {
 							os->add_result(get_id(), w_i->first, XPROBE_MATCH_NO);
+						}
 					for (o_i = options_map.begin(); o_i != options_map.end(); o_i++)
 						if (o_i->second == opt_order) {
 							os->add_result(get_id(), o_i->first, XPROBE_MATCH_YES);
-						} else 
+						} else {
 							os->add_result(get_id(), o_i->first, XPROBE_MATCH_NO);
+						}
 					if (got_timestamp) {
 						if (timestamps[0] == 0)
 							tsv_first = 0;
@@ -206,18 +208,26 @@ int TCP_Handshake_Mod::run_probe(Target *tg, OS_Matrix *os) {
 						for (ts_i = tsval.begin(); ts_i != tsval.end(); ts_i++)
 							if (ts_i->second == tsv_first)
 								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_YES);
+							else
+								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_NO);
 						for (ts_i = tsecr.begin(); ts_i != tsecr.end(); ts_i++)
 							if (ts_i->second == tse_first)
 								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_YES);
+							else
+								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_NO);
 						tsv_first = timestamps[0];
 						tse_first = timestamps[1];
 					} else {
 						for (ts_i = tsval.begin(); ts_i != tsval.end(); ts_i++)  
 							if (ts_i->second == 2) /* NONE */
 								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_YES);
+							else
+								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_NO);
 						for (ts_i = tsecr.begin(); ts_i != tsecr.end(); ts_i++)
 							if (ts_i->second == 2) /* NONE */
 								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_YES);
+							else 
+								os->add_result(get_id(), ts_i->first, XPROBE_MATCH_NO);
 					}
 					if (tg->generate_sig())
 						generate_signature(tg, &sn, request);
@@ -347,7 +357,7 @@ int TCP_Handshake_Mod::fini(void) {
 }
 
 int TCP_Handshake_Mod::parse_keyword(int os_id, const char *kwd, const char *val)  {
-	unsigned int vl;
+	unsigned int vl=0;
 	map<string, Xprobe_Module_Param_TCP *>::iterator m_i;
 	
 	xprobe_debug(XPROBE_DEBUG_SIGNATURES, "Parsing for %i : %s  = %s\n", os_id,  kwd, val);
