@@ -1,4 +1,4 @@
-/* $Id: xprobe_module.h,v 1.5 2003/08/20 05:30:16 mederchik Exp $ */
+/* $Id: xprobe_module.h,v 1.6 2005/02/08 20:00:35 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -40,6 +40,7 @@ class Xprobe_Module {
         string description;
         int mod_id;
         int mod_type;
+		bool enabled;
 		virtual void generate_signature(Target *, ICMP *, ICMP *) { return; }
 		virtual void generate_signature(Target *, TCP *, TCP *) { return; }
    public:
@@ -54,6 +55,9 @@ class Xprobe_Module {
     int get_type(void) { return mod_type; }
     Xprobe_Module(void) { set_name((const char *)"noname"); set_desc("No description is given");}
     Xprobe_Module(int type, const char *nm, const char *desc) { set_type(type); set_name(nm); set_desc(desc); }
+	void enable(void) { enabled = true; }
+	void disable(void) { enabled = false; }
+	bool is_disabled(void) { return (enabled == false);};
     virtual ~Xprobe_Module(void) { return; }
     /* these to be overriden */
     virtual int init(void) =0;
