@@ -1,4 +1,4 @@
-/* $Id: xprobe_module_param.h,v 1.8 2003/08/05 03:35:11 mederchik Exp $ */
+/* $Id: xprobe_module_param.h,v 1.10 2005/02/08 20:00:36 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -36,18 +36,27 @@
 
 using namespace std;
 
-#define XPROBE_MODULE_PARAM_BOOL    1      /* y/n */
-#define XPROBE_MODULE_PARAM_ZNZ     2      /* zero, not zero -- !0, 0 */
-#define XPROBE_MODULE_PARAM_INT     3      /* int - 1234 */
-#define XPROBE_MODULE_PARAM_RANGE   4      /* range - <1, >2, 20-40 */
-#define XPROBE_MODULE_PARAM_ZNZORIG	5		/* zero, not zero, original value(SENT) */
-#define XPROBE_MODULE_PARAM_ZNZVAL	6		/* zero, value, not zero */
+#define XPROBE_MODULE_PARAM_BOOL		1      /* y/n */
+#define XPROBE_MODULE_PARAM_ZNZ			2      /* zero, not zero -- !0, 0 */
+#define XPROBE_MODULE_PARAM_INT			3      /* int - 1234 */
+#define XPROBE_MODULE_PARAM_RANGE		4      /* range - <1, >2, 20-40 */
+#define XPROBE_MODULE_PARAM_ZNZORIG		5		/* zero, not zero, original value(SENT) */
+#define XPROBE_MODULE_PARAM_ZNZVAL		6		/* zero, value, not zero */
+#define XPROBE_MODULE_PARAM_INTLIST		7		/* list of integers (1,2,3,4,...) */
+#define XPROBE_MODULE_PARAM_STRATEGY	8		/* (R)andom, (I)ncremental, 0 */
 
 #define XPROBE_MODULE_PARAM_FUZZY_DELTA     31
 
+
+#define XMP_STRATEGY_RANDOM				2
+#define XMP_STRATEGY_INCREMENTAL		1
+#define XMP_STRATEGY_ZERO				0
+#define XMP_STRATEGY_THRESHOLD			256	
+
 typedef struct xprobe_module_param_val {
     int high;
     int low;
+	vector <int> val_list;
 } xprobe_module_param_t;
 
 
